==> CRM64Pro-0.14.0-docs.zip: CRM64Pro-0.14.0-docs/html/class_c_r_m64_pro_1_1_image_mgr.js <==
var class_c_r_m64_pro_1_1_image_mgr =
[
    [ "info", "class_c_r_m64_pro_1_1_image_mgr.html#a6f448b82c1d5d83c465132d65ee4865b", null ],
    [ "create", "class_c_r_m64_pro_1_1_image_mgr.html#ab487681c83881574d70bfd0957ad8c0b", null ],
    [ "close", "class_c_r_m64_pro_1_1_image_mgr.html#a407f828e6aecfb2ce3884f8f420cc729", null ],
    [ "getCount", "class_c_r_m64_pro_1_1_image_mgr.html#af13ecb96855d2b6053b62f4c878b9e79", null ],
    [ "setName", "class_c_r_m64_pro_1_1_image_mgr.html#a3b9f3195762b2f9aeb4f896184187763", null ],
    [ "closeEx", "class_c_r_m64_pro_1_1_image_mgr.html#a94d2eff703e8404c3818136a2c459f4a", null ],
    [ "get", "class_c_r_m64_pro_1_1_image_mgr.html#a00dd21497a886f254374bf6ce6c4a03e", null ],
    [ "duplicate", "class_c_r_m64_pro_1_1_image_mgr.html#a74356dc9579b0c32152e3719f903f621", null ],
    [ "child", "class_c_r_m64_pro_1_1_image_mgr.html#a65f604f8c21fc04cd447b9eb54d41909", null ],
    [ "isBMP", "class_c_r_m64_pro_1_1_image_mgr.html#a1f0ff44a7d66053ce11e47b888529f10", null ],
    [ "isPNG", "class_c_r_m64_pro_1_1_image_mgr.html#ae7b074ce8fbfcadcb3bf3529d0550121", null ],
    [ "loadFromFile", "class_c_r_m64_pro_1_1_image_mgr.html#a207bbd2d50cda5e1358137a601e81fc1", null ],
    [ "load", "class_c_r_m64_pro_1_1_image_mgr.html#a53945a4290c32b2eab80a5d4e0b88e48", null ],
    [ "load", "class_c_r_m64_pro_1_1_image_mgr.html#ac76573d38ed9d4ccabcfa027ae8af72b", null ],
    [ "loadFromBuffer", "class_c_r_m64_pro_1_1_image_mgr.html#a150e1702078ece69eba5d8ed1c82e12b", null ],
    [ "remove", "class_c_r_m64_pro_1_1_image_mgr.html#ae5a2d1147172fb1301357a1819d7a8de", null ],
    [ "exist", "class_c_r_m64_pro_1_1_image_mgr.html#ad0a2576537f2b3dbf666c5ac36600bfb", null ],
    [ "exist", "class_c_r_m64_pro_1_1_image_mgr.html#a0fbb5dd5826186501358cd9efa0c18c3", null ]
];

==> CRM64Pro-0.15.0-docs.zip: CRM64Pro-0.15.0-docs/html/class_c_r_m64_pro_1_1_image_mgr.js <==
var class_c_r_m64_pro_1_1_image_mgr =
[
    [ "info", "class_c_r_m64_pro_1_1_image_mgr.html#a6f448b82c1d5d83c465132d65ee4865b", null ],
    [ "create", "class_c_r_m64_pro_1_1_image_mgr.html#ab487681c83881574d70bfd0957ad8c0b", null ],
    [ "close", "class_c_r_m64_pro_1_1_image_mgr.html#a407f828e6aecfb2ce3884f8f420cc729", null ],
    [ "getCount", "class_c_r_m64_pro_1_1_image_mgr.html#af13ecb96855d2b6053b62f4c878b9e79", null ],
    [ "setName", "class_c_r_m64_pro_1_1_image_mgr.html#a3b9f3195762b2f9aeb4f896184187763", null ],
    [ "closeEx", "class_c_r_m64_pro_1_1_image_mgr.html#a94d2eff703e8404c3818136a2c459f4a", null ],
    [ "get", "class_c_r_m64_pro_1_1_image_mgr.html#a00dd21497a886f254374bf6ce6c4a03e", null ],
    [ "duplicate", "class_c_r_m64_pro_1_1_image_mgr.html#a74356dc9579b0c32152e3719f903f621", null ],
    [ "child", "class_c_r_m64_pro_1_1_image_mgr.html#a65f604f8c21fc04cd447b9eb54d41909", null ],
    [ "isBMP", "class_c_r_m64_pro_1_1_image_mgr.html#a1f0ff44a7d66053ce11e47b888529f10", null ],
    [ "isPNG", "class_c_r_m64_pro_1_1_image_mgr.html#ae7b074ce8fbfcadcb3bf3529d0550121", null ],
    [ "loadFromFile", "class_c_r_m64_pro_1_1_image_mgr.html#a207bbd2d50cda5e1358137a601e81fc1", null ],
    [ "load", "class_c_r_m64_pro_1_1_image_mgr.html#a53945a4290c32b2eab80a5d4e0b88e48", null ],
    [ "load", "class_c_r_m64_pro_1_1_image_mgr.html#ac76573d38ed9d4ccabcfa027ae8af72b", null ],
    [ "loadFromBuffer", "class_c_r_m64_pro_1_1_image_mgr.html#a150e1702078ece69eba5d8ed1c82e12b", null ],
    [ "loadFromSurface", "class_c_r_m64_pro_1_1_image_mgr.html#ab91930390fa658b080083fa3c0050b0e", null ],
    [ "remove", "class_c_r_m64_pro_1_1_image_mgr.html#ae5a2d1147172fb1301357a1819d7a8de", null ],
    [ "exist", "class_c_r_m64_pro_1_1_image_mgr.html#ad0a2576537f2b3dbf666c5ac36600bfb", null ],
    [ "exist", "class_c_r_m64_pro_1_1_image_mgr.html#a0fbb5dd5826186501358cd9efa0c18c3", null ]
];
